@@ -180,7 +180,7 @@ class GraphTraversalSource(object):
         return self.with_computer(graph_computer, workers, result, persist, vertices, edges, configuration)
 
     def with_computer(self, graph_computer=None, workers=None, result=None, persist=None, vertices=None,
-                  edges=None, configuration=None):
+                      edges=None, configuration=None):
         return self.with_strategies(
             VertexProgramStrategy(graph_computer, workers, result, persist, vertices, edges, configuration))
 
@@ -309,14 +309,30 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("aggregate", *args)
         return self
 
+    def all_(self, *args):
+        self.bytecode.add_step("all", *args)
+        return self
+
     def and_(self, *args):
         self.bytecode.add_step("and", *args)
         return self
 
+    def any_(self, *args):
+        self.bytecode.add_step("any", *args)
+        return self
+
     def as_(self, *args):
         self.bytecode.add_step("as", *args)
         return self
 
+    def as_date(self, *args):
+        self.bytecode.add_step("asDate", *args)
+        return self
+
+    def as_string(self, *args):
+        self.bytecode.add_step("asString", *args)
+        return self
+
     def barrier(self, *args):
         self.bytecode.add_step("barrier", *args)
         return self
@@ -375,10 +391,18 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("coin", *args)
         return self
 
+    def combine(self, *args):
+        self.bytecode.add_step("combine", *args)
+        return self
+
     def concat(self, *args):
         self.bytecode.add_step("concat", *args)
         return self
 
+    def conjoin(self, *args):
+        self.bytecode.add_step("conjoin", *args)
+        return self
+
     def connectedComponent(self, *args):
         warnings.warn(
             "gremlin_python.process.GraphTraversalSource.connectedComponent will be replaced by "
@@ -409,10 +433,26 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("cyclicPath", *args)
         return self
 
+    def date_add(self, *args):
+        self.bytecode.add_step("dateAdd", *args)
+        return self
+
+    def date_diff(self, *args):
+        self.bytecode.add_step("dateDiff", *args)
+        return self
+
     def dedup(self, *args):
         self.bytecode.add_step("dedup", *args)
         return self
 
+    def difference(self, *args):
+        self.bytecode.add_step("difference", *args)
+        return self
+
+    def disjunct(self, *args):
+        self.bytecode.add_step("disjunct", *args)
+        return self
+
     def drop(self, *args):
         self.bytecode.add_step("drop", *args)
         return self
@@ -459,6 +499,10 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("fold", *args)
         return self
 
+    def format_(self, *args):
+        self.bytecode.add_step("format", *args)
+        return self
+
     def from_(self, *args):
         self.bytecode.add_step("from", *args)
         return self
@@ -579,6 +623,10 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("inject", *args)
         return self
 
+    def intersect(self, *args):
+        self.bytecode.add_step("intersect", *args)
+        return self
+
     def is_(self, *args):
         self.bytecode.add_step("is", *args)
         return self
@@ -591,6 +639,10 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("label", *args)
         return self
 
+    def length(self, *args):
+        self.bytecode.add_step("length", *args)
+        return self
+
     def limit(self, *args):
         self.bytecode.add_step("limit", *args)
         return self
@@ -603,6 +655,10 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("loops", *args)
         return self
 
+    def lTrim(self, *args):
+        self.bytecode.add_step("lTrim", *args)
+        return self
+
     def map(self, *args):
         self.bytecode.add_step("map", *args)
         return self
@@ -623,6 +679,10 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("mean", *args)
         return self
 
+    def merge(self, *args):
+        self.bytecode.add_step("merge", *args)
+        return self
+
     def merge_e(self, *args):
         self.bytecode.add_step("mergeE", *args)
         return self
@@ -722,6 +782,10 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("peerPressure", *args)
         return self
 
+    def product(self, *args):
+        self.bytecode.add_step("product", *args)
+        return self
+
     def profile(self, *args):
         self.bytecode.add_step("profile", *args)
         return self
@@ -765,6 +829,18 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("repeat", *args)
         return self
 
+    def replace(self, *args):
+        self.bytecode.add_step("replace", *args)
+        return self
+
+    def reverse(self, *args):
+        self.bytecode.add_step("reverse", *args)
+        return self
+
+    def rTrim(self, *args):
+        self.bytecode.add_step("rTrim", *args)
+        return self
+
     def sack(self, *args):
         self.bytecode.add_step("sack", *args)
         return self
@@ -814,6 +890,10 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("skip", *args)
         return self
 
+    def split(self, *args):
+        self.bytecode.add_step("split", *args)
+        return self
+
     def store(self, *args):
         self.bytecode.add_step("store", *args)
         return self
@@ -822,6 +902,10 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("subgraph", *args)
         return self
 
+    def substring(self, *args):
+        self.bytecode.add_step("substring", *args)
+        return self
+
     def sum_(self, *args):
         self.bytecode.add_step("sum", *args)
         return self
@@ -860,6 +944,14 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("toE", *args)
         return self
 
+    def to_lower(self, *args):
+        self.bytecode.add_step("toLower", *args)
+        return self
+
+    def to_upper(self, *args):
+        self.bytecode.add_step("toUpper", *args)
+        return self
+
     def toV(self, *args):
         warnings.warn(
             "gremlin_python.process.GraphTraversalSource.toV will be replaced by "
@@ -875,6 +967,10 @@ class GraphTraversal(Traversal):
         self.bytecode.add_step("tree", *args)
         return self
 
+    def trim(self, *args):
+        self.bytecode.add_step("trim", *args)
+        return self
+
     def unfold(self, *args):
         self.bytecode.add_step("unfold", *args)
         return self
@@ -975,14 +1071,30 @@ class __(object, metaclass=MagicType):
     def aggregate(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).aggregate(*args)
 
+    @classmethod
+    def all_(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).all_(*args)
+
     @classmethod
     def and_(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).and_(*args)
 
+    @classmethod
+    def any_(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).any_(*args)
+
     @classmethod
     def as_(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).as_(*args)
 
+    @classmethod
+    def as_date(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).as_date(*args)
+
+    @classmethod
+    def as_string(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).as_string(*args)
+
     @classmethod
     def barrier(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).barrier(*args)
@@ -1039,10 +1151,18 @@ class __(object, metaclass=MagicType):
     def coin(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).coin(*args)
 
+    @classmethod
+    def combine(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).combine(*args)
+
     @classmethod
     def concat(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).concat(*args)
 
+    @classmethod
+    def conjoin(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).conjoin(*args)
+
     @classmethod
     def constant(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).constant(*args)
@@ -1063,10 +1183,26 @@ class __(object, metaclass=MagicType):
     def cyclic_path(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).cyclic_path(*args)
 
+    @classmethod
+    def date_add(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).date_add(*args)
+
+    @classmethod
+    def date_diff(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).date_diff(*args)
+
     @classmethod
     def dedup(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).dedup(*args)
 
+    @classmethod
+    def difference(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).difference(*args)
+
+    @classmethod
+    def disjunct(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).disjunct(*args)
+
     @classmethod
     def drop(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).drop(*args)
@@ -1115,6 +1251,10 @@ class __(object, metaclass=MagicType):
     def fold(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).fold(*args)
 
+    @classmethod
+    def format_(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).format_(*args)
+
     @classmethod
     def group(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).group(*args)
@@ -1239,6 +1379,10 @@ class __(object, metaclass=MagicType):
     def inject(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).inject(*args)
 
+    @classmethod
+    def intersect(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).intersect(*args)
+
     @classmethod
     def is_(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).is_(*args)
@@ -1251,6 +1395,10 @@ class __(object, metaclass=MagicType):
     def label(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).label(*args)
 
+    @classmethod
+    def length(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).length(*args)
+
     @classmethod
     def limit(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).limit(*args)
@@ -1263,6 +1411,10 @@ class __(object, metaclass=MagicType):
     def loops(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).loops(*args)
 
+    @classmethod
+    def ltrim(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).ltrim(*args)
+
     @classmethod
     def map(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).map(*args)
@@ -1283,6 +1435,10 @@ class __(object, metaclass=MagicType):
     def mean(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).mean(*args)
 
+    @classmethod
+    def merge(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).merge(*args)
+
     @classmethod
     def merge_e(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).merge_e(*args)
@@ -1355,6 +1511,10 @@ class __(object, metaclass=MagicType):
     def path(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).path(*args)
 
+    @classmethod
+    def product(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).product(*args)
+
     @classmethod
     def project(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).project(*args)
@@ -1387,6 +1547,18 @@ class __(object, metaclass=MagicType):
     def repeat(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).repeat(*args)
 
+    @classmethod
+    def replace(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).replace(*args)
+
+    @classmethod
+    def reverse(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).reverse(*args)
+
+    @classmethod
+    def rTrim(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).rTrim(*args)
+
     @classmethod
     def sack(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).sack(*args)
@@ -1427,6 +1599,10 @@ class __(object, metaclass=MagicType):
     def skip(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).skip(*args)
 
+    @classmethod
+    def split(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).split(*args)
+
     @classmethod
     def store(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).store(*args)
@@ -1435,6 +1611,10 @@ class __(object, metaclass=MagicType):
     def subgraph(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).subgraph(*args)
 
+    @classmethod
+    def substring(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).substring(*args)
+
     @classmethod
     def sum_(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).sum_(*args)
@@ -1475,6 +1655,14 @@ class __(object, metaclass=MagicType):
     def to_e(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).to_e(*args)
 
+    @classmethod
+    def to_lower(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).to_lower(*args)
+
+    @classmethod
+    def to_upper(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).to_upper(*args)
+
     @classmethod
     def toV(cls, *args):
         warnings.warn(
@@ -1491,6 +1679,10 @@ class __(object, metaclass=MagicType):
     def tree(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).tree(*args)
 
+    @classmethod
+    def trim(cls, *args):
+        return cls.graph_traversal(None, None, Bytecode()).trim(*args)
+
     @classmethod
     def unfold(cls, *args):
         return cls.graph_traversal(None, None, Bytecode()).unfold(*args)
@@ -1639,6 +1831,14 @@ def as_(*args):
     return __.as_(*args)
 
 
+def as_date(*args):
+    return __.as_date(*args)
+
+
+def as_string(*args):
+    return __.as_string(*args)
+
+
 def barrier(*args):
     return __.barrier(*args)
 
@@ -1707,6 +1907,14 @@ def cyclic_path(*args):
     return __.cyclic_path(*args)
 
 
+def date_add(*args):
+    return __.date_add(*args)
+
+
+def date_diff(*args):
+    return __.date_diff(*args)
+
+
 def dedup(*args):
     return __.dedup(*args)
 
@@ -1751,6 +1959,10 @@ def fold(*args):
     return __.fold(*args)
 
 
+def format_(*args):
+    return __.format_(*args)
+
+
 def group(*args):
     return __.group(*args)
 
@@ -1855,6 +2067,10 @@ def label(*args):
     return __.label(*args)
 
 
+def length(*args):
+    return __.length(*args)
+
+
 def limit(*args):
     return __.limit(*args)
 
@@ -1867,6 +2083,10 @@ def loops(*args):
     return __.loops(*args)
 
 
+def ltrim(*args):
+    return __.ltrim(*args)
+
+
 def map(*args):
     return __.map(*args)
 
@@ -1975,6 +2195,18 @@ def repeat(*args):
     return __.repeat(*args)
 
 
+def replace(*args):
+    return __.replace(*args)
+
+
+def reverse(*args):
+    return __.reverse(*args)
+
+
+def rTrim(*args):
+    return __.rTrim(*args)
+
+
 def sack(*args):
     return __.sack(*args)
 
@@ -2007,6 +2239,10 @@ def skip(*args):
     return __.skip(*args)
 
 
+def split(*args):
+    return __.split(*args)
+
+
 def store(*args):
     return __.store(*args)
 
@@ -2015,6 +2251,10 @@ def subgraph(*args):
     return __.subgraph(*args)
 
 
+def substring(*args):
+    return __.substring(*args)
+
+
 def sum_(*args):
     return __.sum_(*args)
 
@@ -2047,6 +2287,14 @@ def to_e(*args):
     return __.to_e(*args)
 
 
+def to_lower(*args):
+    return __.to_lower(*args)
+
+
+def to_upper(*args):
+    return __.to_upper(*args)
+
+
 def toV(*args):
     return __.to_v(*args)
 
@@ -2059,6 +2307,10 @@ def tree(*args):
     return __.tree(*args)
 
 
+def trim(*args):
+    return __.trim(*args)
+
+
 def unfold(*args):
     return __.unfold(*args)
 
@@ -2107,6 +2359,10 @@ statics.add_static('and_', and_)
 
 statics.add_static('as_', as_)
 
+statics.add_static('as_date', as_date)
+
+statics.add_static('as_string', as_string)
+
 statics.add_static('barrier', barrier)
 
 statics.add_static('both', both)
@@ -2141,6 +2397,10 @@ statics.add_static('cyclicPath', cyclicPath)
 
 statics.add_static('cyclicpath', cyclic_path)
 
+statics.add_static('date_add', date_add)
+
+statics.add_static('date_diff', date_diff)
+
 statics.add_static('dedup', dedup)
 
 statics.add_static('drop', drop)
@@ -2163,6 +2423,8 @@ statics.add_static('flat_map', flat_map)
 
 statics.add_static('fold', fold)
 
+statics.add_static('format_', format_)
+
 statics.add_static('group', group)
 
 statics.add_static('groupCount', groupCount)
@@ -2213,12 +2475,16 @@ statics.add_static('key', key)
 
 statics.add_static('label', label)
 
+statics.add_static('length', length)
+
 statics.add_static('limit', limit)
 
 statics.add_static('local', local)
 
 statics.add_static('loops', loops)
 
+statics.add_static('ltrim', ltrim)
+
 statics.add_static('map', map)
 
 statics.add_static('match', match)
@@ -2273,6 +2539,12 @@ statics.add_static('range_', range_)
 
 statics.add_static('repeat', repeat)
 
+statics.add_static('replace', replace)
+
+statics.add_static('reverse', reverse)
+
+statics.add_static('rTrim', rTrim)
+
 statics.add_static('sack', sack)
 
 statics.add_static('sample', sample)
@@ -2289,10 +2561,14 @@ statics.add_static('simple_path', simple_path)
 
 statics.add_static('skip', skip)
 
+statics.add_static('split', split)
+
 statics.add_static('store', store)
 
 statics.add_static('subgraph', subgraph)
 
+statics.add_static('substring', substring)
+
 statics.add_static('sum_', sum_)
 
 statics.add_static('tail', tail)
@@ -2311,10 +2587,16 @@ statics.add_static('to_e', to_e)
 
 statics.add_static('toV', toV)
 
+statics.add_static('to_lower', to_lower)
+
+statics.add_static('to_upper', to_upper)
+
 statics.add_static('to_v', to_v)
 
 statics.add_static('tree', tree)
 
+statics.add_static('trim', trim)
+
 statics.add_static('unfold', unfold)
 
 statics.add_static('union', union)
